==> enterprisemodules-ora_config-3.20.0.tar.gz: enterprisemodules-ora_config-3.20.0/lib/puppet/type/shared/ora_config/common_granted.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:common_granted, :array_matching => :all) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Mungers::Upcase
  include Puppet_X::EnterpriseModules::Oracle::GrantProperty
  include Puppet_X::EnterpriseModules::Oracle::Access

  to_translate_to_resource do |_raw_resource|
    #
    # We don't need a value, but we do need the side effects of the super method.
    #
    @all_rights ||= privileges + granted_roles
    nil
  end

  data_type('Optional[Array[String[1]]]')

  validate do |value|
    fail 'You need to specify an Array instead of a comma separated string' if /,/.match?(value)
  end

  desc <<-DESC
    The common grants you want to make sure are granted to the `ora_user` or `ora_role`.

    This property is only functional when applied on container databases.

    It is different from the `common_grants` property in the sense that this is not a full list of the rights, but just the rights
    that are granted to the user

    Here is an example with an `ora_user`:

        ora_user {'scott':
          ...
          common_granted => ['GRANT ANY ROLE'],
          ...
        }

    Here is an example with an `ora_role`:

        ora_role {'app_dba_role':
          ...
          common_granted => ['GRANT ANY ROLE'],
          ...
        }

  DESC

  #
  # This property manages grants without admin options
  #
  def self.admin
    false
  end

  def self.common
    true
  end

  def insync?(_is)
    should.any? { |r| current_rights.include?(r) }
  end

  def granted_rights
    value - current_rights
  end
end

==> enterprisemodules-ora_config-3.22.1.tar.gz: enterprisemodules-ora_config-3.22.1/lib/puppet/type/shared/ora_config/common_granted.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:common_granted, :array_matching => :all) do
  include EasyType
  include PuppetX::EnterpriseModules::Oracle::Mungers::Upcase
  include PuppetX::EnterpriseModules::Oracle::GrantProperty
  include PuppetX::EnterpriseModules::Oracle::Access

  to_translate_to_resource do |_raw_resource|
    #
    # We don't need a value, but we do need the side effects of the super method.
    #
    @all_rights ||= privileges + granted_roles
    nil
  end

  data_type('Optional[Array[String[1]]]')

  validate do |value|
    fail 'You need to specify an Array instead of a comma separated string' if /,/.match?(value)
  end

  desc <<-DESC
    The common grants you want to make sure are granted to the `ora_user` or `ora_role`.

    This property is only functional when applied on container databases.

    It is different from the `common_grants` property in the sense that this is not a full list of the rights, but just the rights
    that are granted to the user

    Here is an example with an `ora_user`:

        ora_user {'scott':
          ...
          common_granted => ['GRANT ANY ROLE'],
          ...
        }

    Here is an example with an `ora_role`:

        ora_role {'app_dba_role':
          ...
          common_granted => ['GRANT ANY ROLE'],
          ...
        }

  DESC

  #
  # This property manages grants without admin options
  #
  def self.admin
    false
  end

  def self.common
    true
  end

  def insync?(_is)
    should.any? { |r| current_rights.include?(r) }
  end

  def granted_rights
    value - current_rights
  end
end
